@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "net/http"
+require "faraday"
 require "yaml"
 require "open3"
 
@@ -10,14 +10,8 @@ module Docker
   #
   class Manager
     VERSIONS = %w[
-      3.1.6
-      3.2.7
-      3.3.7
-    ].freeze
-
-    LINE_EDITORS = %w[
-      readline
-      libedit
+      3.2.9
+      3.3.9
     ].freeze
 
     COMPILERS = %w[
@@ -25,11 +19,10 @@ module Docker
       clang
     ].freeze
 
-    attr_reader :version, :line_editor, :compiler
+    attr_reader :version, :compiler
 
-    def initialize(version:, line_editor:, compiler:)
+    def initialize(version:, compiler:)
       @version = version
-      @line_editor = line_editor
       @compiler = compiler
     end
 
@@ -44,8 +37,6 @@ module Docker
           --build-arg "ruby_download_url=#{download_url}" \
           --build-arg "ruby_download_sha256=#{download_sha256}" \
           --build-arg "compiler=#{compiler}" \
-          --build-arg "line_edit_lib=#{line_editor_package}" \
-          --build-arg "line_edit_config=#{line_editor_configure_flag}" \
           --file "docker/Dockerfile" \
           .
       COMMAND
@@ -102,7 +93,7 @@ module Docker
 
       def release_info
         @release_info ||= YAML.safe_load(
-          Net::HTTP.get(URI.parse(releases_url)),
+          Faraday.get(releases_url).body,
           permitted_classes: [Date]
         )
       end
@@ -153,29 +144,18 @@ module Docker
 
       def for_variants_of(version)
         COMPILERS.each do |compiler|
-          LINE_EDITORS.each do |line_editor|
-            manager = new(
-              version: version,
-              line_editor: line_editor,
-              compiler: compiler
-            )
+          manager = new(
+            version: version,
+            compiler: compiler
+          )
 
-            yield(manager)
-          end
+          yield(manager)
         end
       end
     end
 
     private
 
-    def line_editor_package
-      line_editor == "readline" ? "readline-dev" : "libedit-dev"
-    end
-
-    def line_editor_configure_flag
-      line_editor == "readline" ? "" : "--enable-libedit"
-    end
-
     def download_url
       if version == "head"
         "#{download_url_base}/snapshot.tar.xz"
@@ -208,7 +188,7 @@ module Docker
     end
 
     def tag
-      "deividrodriguez/byebug:#{version}-#{line_editor}-#{compiler}"
+      "deividrodriguez/byebug:#{version}-#{compiler}"
     end
 
     def squish(command)
