@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Byebug
   #
   # Reopens the +info+ command to define the +args+ subcommand
@@ -6,32 +8,28 @@ module Byebug
     #
     # Information about arguments of the current method/block
     #
-    class ProgramSubcommand < Command
-      def regexp
+    class ProgramCommand < Command
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* p(?:rogram)? \s*$/x
       end
 
-      def execute
-        if @state.context.dead?
-          puts 'The program crashed.'
-          excpt = Byebug.last_exception
-          return puts("Exception: #{excpt.inspect}") if excpt
-        end
-
-        puts 'Program stopped. '
-        format_stop_reason @state.context.stop_reason
-      end
-
-      def short_description
-        'Information about the current status of the debugged program.'
-      end
-
-      def description
-        <<-EOD
+      def self.description
+        <<-DESCRIPTION
           inf[o] p[rogram]
 
           #{short_description}
-        EOD
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Information about the current status of the debugged program."
+      end
+
+      def execute
+        puts "Program stopped. "
+        format_stop_reason context.stop_reason
       end
 
       private
@@ -41,9 +39,9 @@ module Byebug
         when :step
           puts "It stopped after stepping, next'ing or initial start."
         when :breakpoint
-          puts 'It stopped at a breakpoint.'
+          puts "It stopped at a breakpoint."
         when :catchpoint
-          puts 'It stopped at a catchpoint.'
+          puts "It stopped at a catchpoint."
         end
       end
     end
