@@ -1,7 +1,6 @@
 # frozen_string_literal: true
 
-require "byebug/command"
-require "irb"
+require_relative "../command"
 require "English"
 
 module Byebug
@@ -28,9 +27,9 @@ module Byebug
     end
 
     def execute
-      unless processor.interface.instance_of?(LocalInterface)
-        return errmsg(pr("base.errors.only_local"))
-      end
+      return errmsg(pr("base.errors.only_local")) unless processor.interface.instance_of?(LocalInterface)
+
+      require "irb"
 
       # @todo IRB tries to parse $ARGV so we must clear it (see #197). Add a
       #   test case for it so we can remove this comment.
