@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
-require "byebug/command"
+require_relative "../command"
 
 module Byebug
   #
-  # Show (and possibily stop) at every line that changes a global variable.
+  # Show (and possibly stop) at every line that changes a global variable.
   #
   class TracevarCommand < Command
     def self.regexp
@@ -32,10 +32,7 @@ module Byebug
     def execute
       var = @match[1]
       return errmsg(pr("trace.errors.needs_global_variable")) unless var
-
-      unless global_variables.include?(:"#{var}")
-        return errmsg(pr("trace.errors.var_is_not_global", name: var))
-      end
+      return errmsg(pr("trace.errors.var_is_not_global", name: var)) unless global_variables.include?(:"#{var}")
 
       stop = @match[2] && @match[2] !~ /nostop/
 
