@@ -1,4 +1,6 @@
-require 'byebug/helpers/var'
+# frozen_string_literal: true
+
+require_relative "../../helpers/var"
 
 module Byebug
   #
@@ -8,30 +10,32 @@ module Byebug
     #
     # Shows global, instance and local variables
     #
-    class AllSubcommand < Command
+    class AllCommand < Command
       include Helpers::VarHelper
 
-      def regexp
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* a(?:ll)? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          v[ar] a[ll]
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Shows local, global and instance variables of self."
+      end
+
       def execute
         var_global
-        var_instance('self')
+        var_instance("self")
         var_local
       end
-
-      def short_description
-        'Shows local, global and instance variables of self.'
-      end
-
-      def description
-        <<-EOD
-          v[ar] a[ll]
-
-          #{short_description}
-        EOD
-      end
     end
   end
 end
