@@ -15,13 +15,13 @@ module Byebug
     end
 
     #
-    # Reads a single line of input using Readline. If Ctrl-D is pressed, it
+    # Reads a single line of input using Reline. If Ctrl-D is pressed, it
     # returns "continue", meaning that program's execution will go on.
     #
     # @param prompt Prompt to be displayed.
     #
     def readline(prompt)
-      with_repl_like_sigint { Readline.readline(prompt) || EOF_ALIAS }
+      with_repl_like_sigint { without_reline_completion { Reline.readline(prompt) || EOF_ALIAS } }
     end
 
     #
@@ -40,5 +40,24 @@ module Byebug
     ensure
       trap("INT", orig_handler)
     end
+
+    #
+    # Disable any Reline completion procs.
+    #
+    # Other gems, for example, IRB could've installed completion procs that are
+    # dependent on them being loaded. Disable those while byebug is the REPL
+    # making use of Reline.
+    #
+    def without_reline_completion
+      orig_completion = Reline.completion_proc
+      return yield unless orig_completion
+
+      begin
+        Reline.completion_proc = ->(_) { nil }
+        yield
+      ensure
+        Reline.completion_proc = orig_completion
+      end
+    end
   end
 end
