@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Byebug
   #
   # Custom interface for easier assertions
@@ -7,21 +9,20 @@ module Byebug
 
     def initialize
       super()
-      @input = []
-      @output = []
-      @error = []
+
+      clear
     end
 
     def errmsg(message)
-      error.concat(message.to_s.split("\n"))
+      error.concat(prepare(message))
     end
 
     def print(message)
-      output.concat(message.to_s.split("\n"))
+      output.concat(prepare(message))
     end
 
     def puts(message)
-      output.concat(message.to_s.split("\n"))
+      output.concat(prepare(message))
     end
 
     def read_command(prompt)
@@ -42,9 +43,9 @@ module Byebug
 
     def inspect
       [
-        'Input:', input.join("\n"),
-        'Output:', output.join("\n"),
-        'Error:', error.join("\n")
+        "Input:", input.join("\n"),
+        "Output:", output.join("\n"),
+        "Error:", error.join("\n")
       ].join("\n")
     end
 
@@ -54,5 +55,13 @@ module Byebug
       cmd = input.shift
       cmd.is_a?(Proc) ? cmd.call : cmd
     end
+
+    private
+
+    def prepare(message)
+      return message.map(&:to_s) if message.respond_to?(:map)
+
+      message.to_s.split("\n")
+    end
   end
 end
